@@ -634,7 +634,7 @@
 #define MYSQL_DATADIR "/var/lib/mysql"
 #define DEFAULT_CHARSET_HOME "/usr"
 #define PLUGINDIR "/usr/lib/mysql/plugin"
-/* #undef DEFAULT_SYSCONFDIR */
+#define DEFAULT_SYSCONFDIR "/etc/mysql"
 #define DEFAULT_TMPDIR P_tmpdir
 
 /* #undef SO_EXT */
